@@ -71,7 +71,7 @@ use Digest::MD5;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.4.8';
+our $VERSION = '1.4.9';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -2776,7 +2776,7 @@ Lemonldap::Portal::* libraries.
 
 =over
 
-=item * ldapServer: server(s) used to retrive session information and to valid
+=item * ldapServer: server(s) used to retrieve session information and to valid
 credentials (localhost by default). More than one server can be set here
 separated by commas. The servers will be tested in the specifies order.
 To use TLS, set "ldap+tls://server" and to use LDAPS, set "ldaps://server"
@@ -2881,7 +2881,7 @@ if exist. Anonymous bind is provided else.
 
 =head3 search
 
-Retrives the LDAP entry corresponding to the user using $self->{filter}.
+Retrieves the LDAP entry corresponding to the user using $self->{filter}.
 
 =head3 setAuthSessionInfo
 
@@ -2904,7 +2904,7 @@ Does nothing by default.
 =head3 authenticate
 
 Method implemented in Lemonldap::NG::Portal::Auth* modules. By default (ldap),
-authenticates the user by rebinding to the LDAP server using the dn retrived
+authenticates the user by rebinding to the LDAP server using the dn retrieved
 with search() and the password.
 
 =head3 grantSession
